@@ -11,7 +11,15 @@
 #' @return A list, with data frame of search results, and list of metadata
 #' @references \url{http://bit.ly/vertnet-wiki}
 #' @details VertNet IDs can be a variety of things, some URIs 
-#' (i.e., with http://...), while others start with \code{urn}. 
+#' (i.e., with http://...), while others start with \code{urn}.
+#' 
+#' Internally in this function we filter data to darwin core terms only. To 
+#' see what terms we use, do 
+#' \code{readLines(
+#' system.file("extdata", "simple_dwc_terms.txt", package = "rvertnet"))}. 
+#' Get in touch with us if these terms need correcting/are out of date. The
+#' terms are from 
+#' https://github.com/tdwg/dwc/blob/master/dist/simple_dwc_horizontal.csv
 #'
 #' @examples \dontrun{
 #' vert_id(ids = "urn:catalog:CM:Herps:116520")
@@ -21,8 +29,7 @@
 #' res <- vert_id(ids)
 #' res$data$occurrenceid
 #' 
-#' # Lots
-#' out <- vertsearch(taxon = "aves", state = "california", limit = 20)
+#' out <- vertsearch(taxon = "aves", state = "california", limit = 5)
 #' (ids <- out$data$occurrenceid)
 #' res <- vert_id(ids)
 #' identical(sort(res$data$occurrenceid), sort(ids))
@@ -43,8 +50,7 @@ vert_id <- function(ids, compact = TRUE, messages = TRUE, ...) {
   }
   names(df) <- tolower(names(df))
   res <- get_terms()
-  df <- merge(res$fullr, df, all = TRUE)[, tolower(res$termlist[,1]) ]
-  df <- df[ -NROW(df), ]
+  df <- df[ , names(df) %in% res ]
   if (compact) { 
     df <- df[ , !sapply(df, function(x) all(is.na(x))) ]
   }
